@@ -161,6 +161,7 @@ class Datatables(View):
     search_fields = ()
     list_filter = ()
     ordering = None
+    include_request = False  # include request in the form init
 
     @classmethod
     def as_view(cls, **initkwars):
@@ -314,7 +315,10 @@ class Datatables(View):
                                 encoder=Codec)
         if 'open' in request.POST:
             instance = self.model.objects.get(id=int(request.POST.get('id')))
-            form = self.get_form()(instance=instance)
+            if self.include_request:
+                form = self.get_form()(instance=instance, request=request)
+            else:
+                form = self.get_form()(instance=instance)
             html_form = self.html_form(instance, request, form, 'POST')
         if 'save' in request.POST:
             instance = self.get_instance(request)
