@@ -15,7 +15,10 @@ def datatables_label(form, fieldname):
 
 @register.filter(name="datatables_field")
 def datatables_field(form, fieldname):
-    return form[fieldname]
+    try:
+        return form[fieldname]
+    except KeyError:
+        return ""
 
 
 @register.filter
@@ -48,4 +51,4 @@ def datatables_column(form, column):
         field = form[name]
         column_group = (field.label, column, 'true')
 
-    return mark_safe('{title: "%s", data: "%s", orderable: %s},' % column_group)
\ No newline at end of file
+    return mark_safe('{title: "%s", data: "%s", orderable: %s},' % column_group)
