@@ -55,6 +55,20 @@ def get_number(entity, length=4):
     return str(code).zfill(length)
 
 
+def json_object(instance, model):
+    if instance:
+        return instance.to_json()
+    else:
+        return model().to_json()
+
+
+def json_choice(choice_name, instance):
+    try:
+        return {'id': getattr(instance, choice_name), 'name': getattr(instance, 'get_%s_display' % choice_name)()}
+    except:
+        return None
+
+
 class Codec(json.JSONEncoder):
     def default(self, obj):
         if hasattr(obj, 'isoformat'):
